import pytest  # noqa
import colorcet as cc

def test_bokeh_palettes_available():
    assert len(cc.palette.items()) == 210
    assert len(cc.palette_n.items()) == 34

def test_bokeh_palette_is_a_list():
    assert isinstance(cc.blues, list)
    assert len(cc.blues) == 256
    assert cc.blues[0] == '#f0f0f0'
    assert cc.blues[-1] == '#3a7bb1'

def test_bokeh_palette_glasbey_do_not_start_with_bw():
    for name in cc.all_original_names(group='glasbey'):
        cmap = cc.palette[name]
        assert isinstance(cmap, list)
        assert len(cmap) == 256
        assert {cmap[0], cmap[1]} != {'#00000', '#ffffff'}


import pytest  # noqa
import colorcet as cc

def test_get_aliases():
    expected = {'kbc', 'CET_L6', 'linear_blue_5_95_c73', 'linear_kbc_5_95_c73'}
    assert set(cc.get_aliases('kbc').split(",  ")) == expected
    assert set(cc.get_aliases('CET_L6').split(",  ")) == expected
    assert set(cc.get_aliases('linear_blue_5_95_c73').split(",  ")) == expected
    assert set(cc.get_aliases('linear_kbc_5_95_c73').split(",  ")) == expected

def test_all_original_names():
    assert len(cc.all_original_names()) == 99

def test_all_original_names_only_aliased():
    assert len(cc.all_original_names(only_aliased=True)) == 32

def test_all_original_names_nopic():
    assert len(cc.all_original_names(group='nopic')) == 15

def test_all_original_names_not_glasbey():
    assert len(cc.all_original_names(not_group='glasbey')) == 91

def test_all_original_names_nopic_and_only_aliased():
    assert len(cc.all_original_names(group='nopic', only_aliased=True)) == 2
